/* Importation des donnees*/
PROC IMPORT DATAFILE = "C:\...\mscm.csv"
    OUT = ds
    REPLACE;
RUN;

/* Modele de trajectoires*/
PROC TRAJ DATA = ds OUTPLOT=OP OUTSTAT=OS OUT=OF OUTEST=OE ITDETAIL;;
    ID id; 
    VAR s2-s6; INDEP t1-t5;
    MODEL LOGIT; NGROUPS 2; ORDER 2 2; 
RUN;
%TRAJPLOT(OP,OS,'Stress mere selon temps','Logistic','Stress','jours')

/* Modeles de ponderation */
PROC LOGISTIC DATA = ds DESCENDING;
    MODEL s2 = s1 i1 married employed csex;
    OUTPUT OUT = ds_denom2 P = p_denom2;
RUN; 
PROC LOGISTIC DATA = ds DESCENDING;
    MODEL s3 = s2 i2 married employed csex;
    OUTPUT OUT = ds_denom3 P = p_denom3;
RUN;
PROC LOGISTIC DATA = ds DESCENDING;
    MODEL s4 = s3 i3 married employed csex;
    OUTPUT OUT = ds_denom4 P = p_denom4;
RUN;
PROC LOGISTIC DATA = ds DESCENDING;
    MODEL s5 = s4 i4 married employed csex;
    OUTPUT OUT = ds_denom5 P = p_denom5;
RUN;
PROC LOGISTIC DATA = ds DESCENDING;
    MODEL s6 = s5 i5 married employed csex;
    OUTPUT OUT = ds_denom6 P = p_denom6;
RUN;

PROC LOGISTIC DATA = ds DESCENDING;
    MODEL s2 = s1;
    OUTPUT OUT = ds_num2 P = p_num2;
RUN; 
PROC LOGISTIC DATA = ds DESCENDING;
    MODEL s3 = s2;
    OUTPUT OUT = ds_num3 P = p_num3;
RUN;
PROC LOGISTIC DATA = ds DESCENDING;
    MODEL s4 = s3;
    OUTPUT OUT = ds_num4 P = p_num4;
RUN;
PROC LOGISTIC DATA = ds DESCENDING;
    MODEL s5 = s4;
    OUTPUT OUT = ds_num5 P = p_num5;
RUN;
PROC LOGISTIC DATA = ds DESCENDING;
    MODEL s6 = s5;
    OUTPUT OUT = ds_num6 P = p_num6;
RUN;

/* Calcul des poids */
DATA poids;
    MERGE ds_num2-ds_num6 ds_denom2-ds_denom6;
    BY id;
    w2 = s2*(p_num2/p_denom2) +
        (1 - s2)*(1 - p_num2)/(1 - p_denom2);
    w3 = s3*(p_num3/p_denom3) +
        (1 - s3)*(1 - p_num3)/(1 - p_denom3);
    w4 = s4*(p_num4/p_denom4) +
        (1 - s4)*(1 - p_num4)/(1 - p_denom4);
    w5 = s5*(p_num5/p_denom5) +
        (1 - s5)*(1 - p_num5)/(1 - p_denom5);
    w6 = s6*(p_num6/p_denom6) +
        (1 - s6)*(1 - p_num6)/(1 - p_denom6);
    w = w2*w3*w4*w5*w6;
    KEEP id w i;
RUN;

PROC MEANS DATA = poids MIN Q1 MEAN MEDIAN Q3 MAX;
    VAR w;
RUN;

/* Analyse MSM */
DATA ds_msm;
    MERGE poids of;
    BY id;
RUN;

/* Brut */
PROC GENMOD DATA = ds_msm;
    CLASS id group;
    MODEL i = group / DIST = normal;
    REPEATED SUBJECT = id;
RUN;
/*
Parameter   Estimate Standard
Error 95% Confidence Limits Z Pr > |Z| 
Intercept   0.1967 0.0550 0.0890 0.3044 3.58 0.0003 
GROUP 1 -0.0667 0.0571 -0.1786 0.0452 -1.17 0.2425 
GROUP 2 0.0000 0.0000 0.0000 0.0000 . 
*/


/* Ajuste */
PROC GENMOD DATA = ds_msm;
    CLASS id group;
    MODEL i = group / DIST = normal;
    REPEATED SUBJECT = id;
    WEIGHT w;
RUN;

/*
Empirical Standard Error Estimates 
Parameter   Estimate Standard
Error 95% Confidence Limits Z Pr > |Z| 
Intercept   0.1327 0.0571 0.0209 0.2446 2.33 0.0200 
GROUP 1 -0.0004 0.0594 -0.1167 0.1160 -0.01 0.9950 
GROUP 2 0.0000 0.0000 0.0000 0.0000 . 
*/



